; filename: IN_10_2.nlogo

extensions [matrix]



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    VARIABLES   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;This section sets up the three different "breeds" used in the model
;and defines global and agent-specific variables

breed [community individual]
breed [mscs msc]
breed [authorities authority]


links-own [name link-info strength partner partname]

turtles-own [ node-id interactions influence information attitude HB? B? N? S? HS? D? ST? I? V? M? interaction-list]
authorities-own [mylist]
globals [ runs slider-max slider-intervals hstotal stotal ntotal btotal hbtotal mat eigenvalues eigenvalue eigenvectors eigenvector network-data max-centrality]




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    SETUP   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;Defines what the "setup" button in the interface tab does

to setup
  clear-all
  reset-ticks
  ask patches[set pcolor white]
  import-attributes
  import-network
  make-links
  ask turtles [change]
  if not new-seed?
  [random-seed 1]
    
end

;===============================================================================

;This section defines the functions called by the "setup" command (above)

to import-attributes
  file-open attribute-file
  while [not file-at-end?][
    let items read-from-string (word "[" file-read-line "]")
    create-community 1 [
      set node-id item 0 items
;      set influence item 1 items
      set attitude item 2 items
      set information item 3 items
;      set shape "person"
      set size 1.5
      set interaction-list[]
      setxy random-xcor random-ycor
      setup-colors
    ]
  ]
  file-close
end 
     
;-----------------------------------------------------------------------

to import-network
  set network-data []
  file-open network-file
  while [not file-at-end?] [
    let thisline file-read-line
    set thisline remove " " thisline
    set thisline (word "[ " (replace-all "," " " thisline) " ]")
    set network-data lput read-from-string thisline network-data
  ]
  file-close
  set mat matrix:from-row-list network-data
  output   
end   

;----------------------------------------------------------------------

to-report replace-all [string1 with-string in-string]
  while [ member? string1 in-string ] [
    let index position string1 in-string
    set in-string replace-item index in-string with-string
  ] 
  report in-string
end

;----------------------------------------------------------------------

to make-links
  ask turtles [
    let my-list matrix:get-row mat who
    foreach my-list [
      if ? != 0 [
        let partner turtle position ? my-list
        if partner != nobody[
        create-link-to turtle position ? my-list[
          set link-info ?
          set strength abs link-info
          set thickness 0.025 * strength
          if link-info > 0 [
            set color blue ]
          if link-info < 0 [
            set color red ]
          if strength = 0 [
            die] 
        ]
        set my-list replace-item (position ? my-list) my-list 0
      ]
      ]
    ]
  ]
end

;-------------------------------------------------------------------


;------------------------------------------------------------------

to setup-colors
 ;sets the color of each agent based on their "attitude" variable
    if attitude = -2 [set color red]
    if attitude = -1 [set color orange]
    if attitude = 0 [set color yellow]
    if attitude = 1 [set color green]
    if attitude = 2 [set color blue]
end





;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;   GO   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to go1
   ask turtles [move-to patch 0 0]
   ask turtles [ define]
   ask turtles [change]
   ask links[decay update]
   ask turtles [layout-circle community 18]
   tick
;   make-matrix
;   output-print matrix:pretty-print-text mat
;   if (mat != matrix:transpose mat) and (reciprocity = 100) [user-message "Asymmetric Matrix!!!"]
end
  
;----------------------------------------------------------------------------------------------

;defines what the "go" button does

to go
;  if not any? community with [color != red] [stop ];layout-circle community 18]
;  if not any? community with [color != orange] [stop ];layout-circle community 18]  
;  if not any? community with [color != yellow] [stop];layout-circle community 18]
;  if not any? community with [color != green] [stop];layout-circle community 18]
;  if not any? community with [color != blue] [stop];layout-circle community 18]
  if ticks = 20000 [stop]
;  if (mat != matrix:transpose mat) and (reciprocity = 100) [user-message "Asymmetric Matrix!!!"]                                      
  ask turtles [ move ]                                                               
  ask community [educate define change]                                           
  ask links [decay update]
  ask turtles [set interaction-list[]]
  make-matrix                                                                 
  totals
  tick
end

;=========================================================================================

to move                                                                              
    right random 360                                                                 
    forward 1
end

;-----------------------------------------------------------------------

to educate  
  if any? mscs-here and attitude = -2
  [set information information + 2 set interactions interactions + 1]
  if any? mscs-here and attitude = -1
  [set information information + 4 set interactions interactions + 1]
  if any? mscs-here and attitude = 0
  [set information information + 6 set interactions interactions + 1]
  if any? mscs-here and attitude = 1
  [set information information + 7 set interactions interactions + 1]
  if any? mscs-here and attitude = 2
  [set information information + 8 set interactions interactions + 1]  
end

;----------------------------------------------------------------------



;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================



;                                                                       TEST INTERACTION



;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================

to define
  if influence?[
    let subordinates other community-here with [
      influence < [influence] of myself]
    if any? subordinates
    [ask subordinates [sub-decide]]]
  if peers?[
    let peers other community-here with [
      influence = [influence] of myself and 
      not member? who [interaction-list] of myself]
    if any? peers
    [ask peers [peer-decide]]]
end

to sub-decide
  let desirability count my-out-links / max-centrality
  ifelse desirability >= attachment-preference
    [global-interact]
    [let x random-float 1
    if x >= attachment-preference
    [global-interact]]
end

to peer-decide
  let desirability count my-out-links / max-centrality
  ifelse desirability >= attachment-preference
    [local-interact]
    [let x random-float 1
    if x >= attachment-preference
    [local-interact]]
  set interaction-list sentence interaction-list [who] of myself
end

to global-interact
  let me myself
  let you self
  let new-info 0.25 * ([influence] of myself - influence) * sign ([attitude] of myself - attitude) * 10 
  set interactions interactions + 1 
  set information information + new-info 
  if-else any? my-in-links with [end1 = me]
  [ask my-in-links with [end1 = me][
      set link-info link-info + new-info]] 
  [create-link-from me [
      set link-info link-info + new-info]] 
  ask me [
    let recip-info (- new-info) * (reciprocity / 100) 
    set interactions interactions + 1 
    set information information + recip-info
    if-else any? my-in-links with [end1 = you]
    [ask my-in-links with [end1 = you][
        set link-info link-info + recip-info]]
    [create-link-from myself [
        set link-info link-info + recip-info]]
  ]
end

to local-interact
  let me myself
  let you self
  let meinf random-normal 0.5 0.16666666666667
  let youinf random-normal 0.5 0.16666666666667
  let new-info abs (meinf - youinf) * sign ([attitude] of myself - attitude) * 10
  set interactions interactions + 1
  set information information + new-info
  set interaction-list sentence interaction-list [who] of myself 
  if-else any? my-in-links with [end1 = me]
  [ask my-in-links with [end1 = me][
    set link-info link-info + new-info]] 
  [create-link-from me [
    set link-info link-info + new-info]]
  ask me [
    let recip-info (- new-info) * (reciprocity / 100) 
    set interactions interactions + 1 
    set information information + recip-info 
    if-else any? my-in-links with [end1 = you]
    [ask my-in-links with [end1 = you][
      set link-info link-info + recip-info]]
    [create-link-from myself [
      set link-info link-info + recip-info]]
  ]
end



;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================
;===============================================================================================================================================================================



;...................................................................
    
to change                                                                ;defines the term "change
  if information > 50 [                                                  ;when an individual or authority reaches a certain threshold in information, their "attitude" changes
    set information 50]
  if information < 0 [
    set information 0]
  if information >= 40[                                                  ;high supporter = >40, supporter = 30-40, neutral = 20-30, blocker = 10-20, high blocker = <20
    set attitude  2 ] 
  if information < 40[
    set attitude 1 ] 
  if information < 30[
    set attitude 0 ]
  if information < 20[
    set attitude -1 ]
  if information < 10 [
    set attitude -2 ]
  setup-colors
 
  ifelse size-nodes? [
    if influence = -2 [
      set size 1]
    if influence = -1 [
      set size 1.5]
    if influence = 0 [
      set size 2]
    if influence = 1 [
      set size 2.5]
    if influence = 2 [
      set size 3]]
  [set size 1.5]
  

  set max-centrality max [count out-link-neighbors] of community ;count [my-out-links] of max-one-of community [count my-out-links];count turtles - 1;
  ifelse max-centrality != 0
  [if count my-out-links >= 0.8 * max-centrality [
    set influence 2]
  if (0.6 * max-centrality <= count my-out-links) and (count my-out-links < 0.8 * max-centrality) [
    set influence 1]   
  if (0.4 * max-centrality <= abs count my-out-links) and (count my-out-links < 0.6 * max-centrality) [
    set influence 0]
  if (0.2 * max-centrality <= abs count my-out-links) and (count my-out-links < 0.4 * max-centrality) [
    set influence -1]
  if abs count my-out-links < 0.2 * max-centrality [
    set influence -2]]
  [set max-centrality 0.00000000000001
    set influence -2] 
end

;................................................................................

to make-matrix
; create an nXn matrix filled with zeros where n is the number of turtles
  set mat matrix:make-constant count turtles count turtles 0
  foreach sort turtles[
  ask ? [
;   each turtle creates a list from the corresponding row of the matrix
    let my-list matrix:get-row mat who
;   each turtle creates a list of the ID# of each turtle it's linked to
    let my-link-list sort [who] of  out-link-neighbors
;   each turtle creates a list of the "link-info" value for its out-links
;   sorted by the turtles that it's linked to
    let sorted-link-info map [[abs link-info] of ?] sort my-out-links
;   each turtle replaces the items in its "my-list" that have an index 
;   corresponding to the values in its "my-link'list". zeros are replace with ones
    foreach my-link-list[
      set my-list replace-item ? my-list "x"
    ]
    foreach sorted-link-info [
      set my-list replace-item (position "x" my-list) my-list ?
    ]
    matrix:set-row mat who my-list 
  ]
  ]
end

;................................................................................

to normalize-eigenvectors
  set eigenvalue  max eigenvalues
  set eigenvector matrix:get-column eigenvectors (position eigenvalue eigenvalues)
  foreach eigenvector[
    set eigenvector replace-item (position ? eigenvector)  eigenvector abs ?
  ]
  let vector-mag reduce + eigenvector
end
  
;..............................................................................

to set-label
  Set label-color black
  set label who
;  ifelse show-information?                                                           ;if the show-information? switch is on, the "information" variable is shown for each actor
;    [set label information]
;    [set label ""]
;    
;  ifelse show-influence?                                                             ;if the show-influence? switch is on, the "influence" variable is shown for each actor
;    [set label influence]
;    [set label ""]  
;    
;  ifelse show-who?                                                                   ;if the show-who? switch is on, the "who" variable is shown for each actor
;    [set label who]
;    [set label ""] 
end  

;...............................................................................

to decay
  let old-link-info abs link-info
  let new-link-info abs link-info - decay-rate
  ifelse (sign old-link-info != sign new-link-info) or (new-link-info = 0)
    [die]
    [set link-info new-link-info * sign (link-info * new-link-info)]
  set strength abs link-info
end

;...................................................................................

to update
  ifelse link-information? 
  [let info-label precision link-info 2 set label-color black set label info-label]
  [set label ""]
  
  set strength abs link-info - decay-rate
  set thickness 0.025 * strength
  if link-info > 0 [
    set color blue ]
  if link-info < 0 [
    set color red ]
  if strength = 0 [
    die] 
end

;...................................................................................

to-report sign [ n ]                                                                 ;reporting the sign of a variable
  if n > 0 [ report 1 ]
  if n < 0 [ report -1 ]
  report 0
end

to-report signif [n]
  
end

;--------------------------------------------------------------------------------

to totals
  set hbtotal hbtotal + count community with [color = red] 
  set btotal btotal + count community with [color = orange]
  set ntotal ntotal + count community with [color = yellow]
  set stotal stotal + count community with [color = green]
  set hstotal hstotal + count community with [color = blue]
end




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;    APPENDAGE CODE  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;-------------------------------------  WRITE TO FILE  ---------------------------------------

to write-to-file
;  file-close-all
;  if file-exists? "link partnerships.txt"[
;    file-delete "link partnerships.txt"]
  file-open "link partnerships.txt"
  ask links [
    ask links [ set name sentence [who] of end1 [who] of end2]
    set partner links with [name = [reverse name] of myself]
    file-print (sentence ticks name [[who] of end1] of partner [[who] of end2] of partner strength [strength] of partner)
  ]
end



;------------------------------------------  LAYOUT -------------------------------------------

to layout-circle?
  layout-circle community 15
end

;--------------------------------------------------------------------------

to layout-radial?
 let root-agent max-one-of turtles [ 
   count in-link-neighbors + count out-link-neighbors]
 layout-radial community links root-agent 
end

;------------------------------------------------------------------

to layout-spring?
  ;; the number 3 here is arbitrary; more repetitions slows down the
  ;; model, but too few gives poor layouts
  repeat 3 [
    ;; the more turtles we have to fit into the same amount of space,
    ;; the smaller the inputs to layout-spring we'll need to use
    let factor sqrt count turtles
    ;; numbers here are arbitrarily chosen for pleasing appearance
    layout-spring turtles links (1 / factor) (divisor / factor) (1 / factor)
    display  ;; for smooth animation
  ]
  ;; don't bump the edges of the world
  let x-offset max [xcor] of turtles + min [xcor] of turtles
  let y-offset max [ycor] of turtles + min [ycor] of turtles
  ;; big jumps look funny, so only adjust a little each time
  set x-offset limit-magnitude x-offset 0.1
  set y-offset limit-magnitude y-offset 0.1
  ask turtles [ setxy (xcor - x-offset / 2) (ycor - y-offset / 2) ]
end

;.....................................................................

to-report limit-magnitude [number limit]
  if number > limit [ report limit ]
  if number < (- limit) [ report (- limit) ]
  report number
end

;---------------------------------------  MAKE MOVIE   ----------------------------------------

to make-movie

  ;; prompt user for movie location
  user-message "First, save your new movie file (choose a name ending with .mov)"
  let path user-new-file
  if not is-string? path [ stop ]  ;; stop if user canceled

  ;; run the model
  setup
  layout-radial?
  movie-start path
;  movie-set-frame-rate 100
  movie-grab-view
  while [ 
    (not all? community [color = red] and
    not all? community [color = orange] and
    not all? community [color = yellow] and 
    not all? community [color = green] and
    not all? community [color = blue] and 
    ticks < 20000)
    ]
    [ go
      movie-grab-view ]

  ;; export the movie
  layout-circle?
  movie-grab-view
  movie-close
  user-message (word "Exported movie to " path)
end




;---------------------------------------  OUTPUT  ----------------------------------------------

to output
  output-print "Adjacency Matrix (mat)"
  output-print matrix:pretty-print-text mat  

  set eigenvalues matrix:real-eigenvalues mat
;  output-print "Eigenvalues"
;  output-print eigenvalues
;  
  set eigenvectors matrix:eigenvectors matrix:transpose mat
;  output-print "Eigenvectors"
;  output-print matrix:pretty-print-text eigenvectors
 
  
  normalize-eigenvectors
  output-print "Maximum Eigenvalue"
  output-print precision eigenvalue 4
  

;  foreach eigenvector[
;    set eigenvector replace-item ? eigenvector abs ?]
  output-print "Eigenvector of Maximum Eigenvalue"
  output-print eigenvector
end
@#$#@#$#@
GRAPHICS-WINDOW
229
110
720
622
18
18
13.0
1
10
1
1
1
0
0
0
1
-18
18
-18
18
1
1
1
ticks
30.0

BUTTON
82
10
145
43
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
732
104
996
250
Social License
Timesteps
License Levels
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"high blockers" 1.0 0 -2674135 true "" "plot count community with [ attitude = -2 ]"
"blockers" 1.0 0 -955883 true "" "plot count community with [ attitude = -1 ]"
"neutral" 1.0 0 -1184463 true "" "plot count community with [ attitude = 0 ]"
"supporters" 1.0 0 -10899396 true "" "plot count community with [ attitude = 1 ]"
"high supporters" 1.0 0 -13345367 true "" "plot count community with [ attitude = 2 ]"

BUTTON
5
49
111
82
layout-radial?
layout-radial?
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
3
160
175
193
reciprocity
reciprocity
0
100
0
1
1
NIL
HORIZONTAL

BUTTON
6
10
75
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
4
447
204
597
License Distribution
License Levels
Frequency
-2.0
3.0
0.0
10.0
true
false
"set-plot-x-range -2 3\nset-plot-y-range -1 count turtles\nset-histogram-num-bars 5\nhistogram [attitude] of community" ""
PENS
"default" 1.0 1 -2674135 true "" "histogram [attitude] of community"

SWITCH
4
299
150
332
link-information?
link-information?
1
1
-1000

SWITCH
3
264
123
297
size-nodes?
size-nodes?
1
1
-1000

SLIDER
3
194
175
227
decay-rate
decay-rate
0
0.0025
0
0.0001
1
NIL
HORIZONTAL

SLIDER
3
229
175
262
attachment-preference
attachment-preference
0
1
0
0.01
1
NIL
HORIZONTAL

PLOT
730
255
996
414
Links
Timesteps
Number of Links
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count links"

BUTTON
114
49
218
82
NIL
layout-circle?
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
4
88
114
121
NIL
layout-spring?
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
228
10
492
84
attribute-file
IN_20_attributes.txt
1
0
String

OUTPUT
239
642
724
929
19

INPUTBOX
499
10
768
85
network-file
IN_20_network_directed_valued.csv
1
0
String

PLOT
729
424
998
599
Influence
Timesteps
Influence Levels
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Dominant" 1.0 0 -5825686 true "" "plot count turtles with [influence = 2]"
"Strong" 1.0 0 -13345367 true "" "plot count turtles with [influence = 1]"
"Influential" 1.0 0 -11221820 true "" "plot count turtles with [influence = 0]"
"Vulnerable" 1.0 0 -13840069 true "" "plot count turtles with [influence = -1]"
"Marginal" 1.0 0 -1184463 true "" "plot count turtles with [influence = -2]"

SWITCH
5
409
109
442
new-seed?
new-seed?
0
1
-1000

SWITCH
5
336
95
369
peers?
peers?
0
1
-1000

PLOT
2
601
202
751
Influence Distribution
Influence Levels
Frequency
0.0
10.0
0.0
10.0
true
false
"set-plot-x-range -2 3\nset-plot-y-range -1 count turtles\nset-histogram-num-bars 5\nhistogram [influence] of community" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram [influence] of community"

SWITCH
5
373
111
406
influence?
influence?
0
1
-1000

INPUTBOX
116
85
219
145
divisor
50
1
0
Number

BUTTON
6
122
103
155
NIL
make-movie
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

@#$#@#$#@
## WHAT IS IT?

This model shows the behavior of actors in a land dispute with MSC.  MSC wants to be able to use a portion of land for storing waste generated at the mine.  They have the approval of the larger community, but there are several local families who use that land for grazing and believe that they should be financially compensated.  In order to understand how much time and resources MSC needs to put into this problem, it has identified who the major actors are, and what level of influence they have over other members of the community.

## HOW IT WORKS

There are three different kinds of agents at play here.  Individuals, MSC, and government authorities.  Currently, individuals interact with MSC, the local authorities, and each other.  The rules that define interactions are different depending on who is interacting with whom. 

## HOW TO USE IT

This section could explain how to use the model, including a description of each of the items in the interface tab.

## THINGS TO NOTICE

This section could give some ideas of things for the user to notice while running the model.

## THINGS TO TRY

This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.

## EXTENDING THE MODEL

This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.

## CREDITS AND REFERENCES

This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="normalization" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles with [attitude = -2]</metric>
    <metric>count turtles with [attitude = -1]</metric>
    <metric>count turtles with [attitude = 0]</metric>
    <metric>count turtles with [attitude = 1]</metric>
    <metric>count turtles with [attitude = 2]</metric>
  </experiment>
  <experiment name="experiment" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>export-plot "Attitudes" (word "results" random-float 1.0 ".csv")</final>
    <metric>count mscs</metric>
  </experiment>
  <experiment name="Exp_CD_HB" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>export-interface (word "interface" negative-percent behaviorspace-run-number ".png")</final>
    <enumeratedValueSet variable="negative-percent">
      <value value="0"/>
      <value value="100"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>file-open "link-raw.csv"
ask links [file-print sentence [who] of both-ends link-info]
file-close</final>
  </experiment>
  <experiment name="attachment preference" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go1</go>
    <exitCondition>ticks = 1</exitCondition>
    <metric>count links</metric>
    <steppedValueSet variable="attachment-preference" first="0" step="0.1" last="1"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 105 195
Line -7500403 true 150 150 195 195

@#$#@#$#@
0
@#$#@#$#@
